@@ -6,12 +6,14 @@
 ## packages: [python3-univention-directory-manager]
 ## bugs: [47316]
 
+import base64
 import os
 from collections import namedtuple
 from unittest import TestCase, main
 
 import univention.debug as ud
 import univention.logging
+from univention.admin.syntax import jpegPhoto
 from univention.testing.strings import random_string, random_username
 from univention.udm import UDM
 
@@ -40,9 +42,11 @@ class TestUdmUsersBasic(TestCase):
         jpg_content = open(f'{CWD}/example_user_jpeg_photo.jpg', 'rb').read()
         obj.props.jpegPhoto = jpg_content
         obj.save()
+
+        encoded_jpg_photo = base64.b64decode(jpegPhoto.parse(base64.b64encode(jpg_content).decode('ascii')))
         try:
             obj = user_mod.get(obj.dn)
-            assert obj.props.jpegPhoto.raw == jpg_content
+            assert obj.props.jpegPhoto.raw == encoded_jpg_photo
             assert obj.props.jpegPhoto.content_type.mime_type == 'image/jpeg'
             assert obj.props.jpegPhoto.content_type.encoding == 'binary'
 
@@ -50,7 +54,7 @@ class TestUdmUsersBasic(TestCase):
             obj_.props.jpegPhoto = obj.props.jpegPhoto
             obj_.save()
             obj_ = user_mod.get(obj.dn)
-            assert obj_.props.jpegPhoto.raw == jpg_content
+            assert obj_.props.jpegPhoto.raw == encoded_jpg_photo
             assert obj_.props.jpegPhoto.content_type.mime_type == 'image/jpeg'
             assert obj_.props.jpegPhoto.content_type.encoding == 'binary'
         finally:
