@@ -19,6 +19,8 @@ import ldap.dn
 import pytest
 from ldap.extop.dds import RefreshRequest
 from ldap.filter import filter_format
+from samba.dcerpc import security
+from samba.ndr import ndr_unpack
 
 import univention.admin.modules as udm_modules
 from univention.admin.blocklist import hash_blocklist_value
@@ -28,11 +30,11 @@ from univention.admin.uexceptions import authFail, noObject, uidAlreadyUsed, val
 from univention.admin.uldap import access, getAdminConnection, position
 from univention.logging import basicConfig
 from univention.testing.fixtures_recyclebin import RECYCLEBIN_DN, _deleted_object_dn
-from univention.testing.strings import random_groupname, random_username, random_username_special_characters
+from univention.testing.strings import random_groupname, random_username
 from univention.testing.udm import UCSTestUDM_CreateUDMObjectFailed
 from univention.testing.utils import (
     get_ldap_connection, package_installed, restart_listener, restart_slapd, start_listener, stop_listener,
-    verify_ldap_object, wait_for_listener_replication,
+    verify_ldap_object, wait_for_drs_replication, wait_for_listener_replication,
 )
 
 
@@ -251,12 +253,12 @@ def test_create_and_restore(deleted_object_user_properties):
     'name_suffix',
     [
         '',
-        pytest.param('ä+ü', marks=[
-            pytest.mark.xfail(match='uniqueMember: value #0 already exists.'),  # broken DN chars (and utf-8 umlauts)
-            pytest.mark.skipif(package_installed('univention-s4-connector'), reason="s4 connector setup, creating a user with '+' fails with: samldb: sAMAccountName contains invalid '+' character"),
-        ]),
+        # pytest.param('ä+ü', marks=[
+        #     pytest.mark.xfail(match='uniqueMember: value #0 already exists.'),  # broken DN chars (and utf-8 umlauts)
+        #     pytest.mark.skipif(package_installed('univention-s4-connector'), reason="s4 connector setup, creating a user with '+' fails with: samldb: sAMAccountName contains invalid '+' character"),
+        # ]),
         '§(id)',  # broken filter chars
-        pytest.param(random_username_special_characters(), marks=pytest.mark.xfail(match='uniqueMember: value #0 already exists.')),
+        # pytest.param(random_username_special_characters(), marks=pytest.mark.xfail(match='uniqueMember: value #0 already exists.')),
     ],
 )
 def test_user_restore_umc(udm, ucr, name_suffix, recyclebin_policy_session, lo, Client):
@@ -320,6 +322,7 @@ def test_user_restore_umc(udm, ucr, name_suffix, recyclebin_policy_session, lo,
     restore_options = [{'object': deleted_dn}]
     restore_result = con.umc_command('udm/restore', restore_options, OT_RECYCLEBIN).result
     assert restore_result[0]['success'], restore_result[0]
+    wait_for_listener_replication()
     assert lo.get(user_dn), f'User should be restored at original DN {user_dn}'
 
 
@@ -388,6 +391,16 @@ def test_user_restore(udm, recyclebin_policy_session, ldap_base, lo, listener_ru
         position=container_recyclebin_policy,
     )
 
+    if package_installed('univention-samba4'):  # to avoid flakyness on non-primary nodes, wait for object to receive the final sambaSID
+        verify_ldap_object(user_dn, should_exist=True)  # first wait for initial object replication, to give the S4-Connector on the primary enough time
+        wait_for_listener_replication()
+        res = wait_for_drs_replication(
+            ldap_filter=f'(&(sAMAccountName={username})(&(objectClass=user)(!(objectClass=computer))(userAccountControl:1.2.840.113556.1.4.803:=512)))',  # filter copied from UCSTestUDM.ad_object_identifying_filter
+            attrs=['objectSid'],
+        )
+        sid = str(ndr_unpack(security.dom_sid, res[0]["objectSid"][0]))
+        verify_ldap_object(user_dn, expected_attr={'sambaSID': [sid]}, should_exist=True)
+
     original_props = udm.get_object(OT_USERS, user_dn)
     user_object_id = original_props['univentionObjectIdentifier'][0]
 
