@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner python3
+#!/usr/share/ucs-test/runner pytest-3 -s -l -vvv
 ## desc: Check whether SSO is not possible with wrong password
 ## tags:
 ##  - saml
@@ -15,15 +15,10 @@ import univention.testing.udm as udm_test
 import samltest
 
 
-def main():
+def test_saml_wrong_password():
     with udm_test.UCSTestUDM() as udm:
         testcase_user_name = udm.create_user()[1]
-        SamlSession = samltest.SamlTest(testcase_user_name, 'Wrong password')
+        saml_session = samltest.SamlTest(testcase_user_name, 'Wrong password')
 
         with pytest.raises(samltest.SamlAuthenticationFailed):
-            SamlSession.login_with_new_session_at_IdP()
-
-
-if __name__ == '__main__':
-    main()
-    print("Success: It is not possible to login with a wrong password")
+            saml_session.login_with_new_session_at_IdP()
